import QtQuick 2.0
import Ubuntu.Components 0.1
import "components"
import Ubuntu.Components.ListItems 0.1 as ListItem
import "js/urpslogic.js" as UrpsLogic
import QtQuick.LocalStorage 2.0

/*!
    \brief MainView with a Label and Button elements.
*/

MainView {
    id: mainView
    width: units.gu(50)
    height: units.gu(75)

    headerColor: "#DEEDE3" //"#00688B"
    backgroundColor: "#DEEDE3" //"#00B2EE"
    footerColor: "#DEEDE3" //"#33A1C9"

    //Here will begin the database code:

    property string gameLength: getSetting("gameLength")
    property string playerName: getSetting("playerName")
    signal buttonClicked
    property var db: null

      function openDB() {
          if(db !== null) return;

          // db = LocalStorage.openDatabaseSync(identifier, version, description, estimated_size, callback(db))
          db = LocalStorage.openDatabaseSync("URPS", "0.1", "Ubuntu Rock Paper Scissors", 100000);

          try {
              db.transaction(function(tx){
                  tx.executeSql('CREATE TABLE IF NOT EXISTS settings(key TEXT UNIQUE, value TEXT)');
                  var table  = tx.executeSql("SELECT * FROM settings");
                  // Seed the table with default values
                  if (table.rows.length == 0) {
                      //tx.executeSql('INSERT INTO settings VALUES(?, ?)', ["distro", "Ubuntu"]);
                      //tx.executeSql('INSERT INTO settings VALUES(?, ?)', ["foo", "Bar"]);
                      tx.executeSql('INSERT INTO settings VALUES(?, ?)', ["gameLength", "1"]);
                      tx.executeSql('INSERT INTO settings VALUES(?, ?)', ["playerName", "RPS Player"]);
                      console.log('Settings table added');
                  };
              });
          } catch (err) {
              console.log("Error creating table in database: " + err);
          };
      }


      function saveSetting(key, value) {
          openDB();
          db.transaction( function(tx){
              tx.executeSql('INSERT OR REPLACE INTO settings VALUES(?, ?)', [key, value]);
          });
      }

      function getSetting(key) {
          openDB();
          var res = "";
          db.transaction(function(tx) {
              var rs = tx.executeSql('SELECT value FROM settings WHERE key=?;', [key]);
              res = rs.rows.item(0).value;
          });
          return res;
      }

    //Here will end the database code.

        PageStack {
            id: pageStack
            Component.onCompleted: push(startTab)

            Tabs {
                id: startTab
                Tab {
                    title: i18n.tr("Rock, Paper, Scissors!")
                    page: Page {
                        Button {
                                 anchors.centerIn: parent
                                    id: button
                                    width: units.gu(15)
                                        height: units.gu(5)
                                    text: i18n.tr("New Game")
                                    pressed: false
                                    onClicked: pageStack.push(urpsOptions)
                               }
                    }
                }
                Tab {
                    title: i18n.tr("About")
                    page: Page {
                        Label {
                            anchors.centerIn: parent
                            text: i18n.tr("The About Tab is still in development.")
                        }
                    }
                }
            }


            Page {
                id: urpsOptions
                visible: false
               title: i18n.tr("Options")



                Item{
                    id: nameInputItem
                    anchors.top: parent.top
                    anchors.topMargin: 5
                    anchors.left: parent.left
                    anchors.leftMargin: 5

                   Label {
                       id: nameDescription



                       text: i18n.tr("Please enter the \n player's name: ")
                          fontSize: "medium"
                      }



                                 TextField {
                                     id: playerNameInput
                                     anchors.left: nameDescription.right
                                     anchors.leftMargin: 5
                                     placeholderText: i18n.tr("Player 1")
                                        hasClearButton: true
                                    }


                                 /*Button {
                                     id: playerNameSendButton
                                     anchors.left: playerNameInput.right
                                     anchors.leftMargin: 5
                                     anchors.rightMargin: 5
                                     width: units.gu(5)
                                     height: units.gu(5)
                                     text: i18n.tr("")
                                     onClicked: print("clicked text-only Button")
                                 }*/



               }

                                OptionSelector {
                                    id: gameLengthToggle
                                    text: i18n.tr("Please selct how many rounds you want to play")
                                    anchors.left: parent.left
                                    anchors.leftMargin: 0
                                    anchors.verticalCenter: parent.verticalCenter


                                    model:
                                        [i18n.tr("1"),
                                        i18n.tr("3"),
                                        i18n.tr("5"),
                                        i18n.tr("7"),
                                        i18n.tr("9"),
                                        i18n.tr("11"),
                                        i18n.tr("13"),
                                        i18n.tr("15")]
                                }








                           Button {
                               //spacing: units.gu(2)
                                    //anchors.verticalCenter: parent.verticalCenter; anchors.bottom: parent.Bottom;
                                       id: startGameButton
                                       width: units.gu(15)
                                       height: units.gu(5)
                                       text: i18n.tr("Start Game")
                                       iconPosition: ("left")
                                       anchors.bottom: parent.bottom
                                       anchors.bottomMargin: 5
                                       anchors.right: parent.right
                                       anchors.rightMargin: 5
                                       pressed: false
                                       onClicked: {


                                            if (gameLengthToggle.selectedIndex === 0){
                                                var gameLength = 1;
                                            }else if (gameLengthToggle.selectedIndex === 1){
                                                var gameLength = 3;

                                            }else if (gameLengthToggle.selectedIndex === 2){
                                                var gameLength = 5;

                                            }else if (gameLengthToggle.selectedIndex === 3){
                                                var gameLength = 7;

                                            }else if (gameLengthToggle.selectedIndex === 4){
                                                var gameLength = 9;

                                            }else if (gameLengthToggle.selectedIndex === 5){
                                                var gameLength = 11;

                                            }else if (gameLengthToggle.selectedIndex === 6){
                                                var gameLength = 13;

                                            }else{
                                                var gameLength = 15;

                                            }
                                            console.log("Saved " + gameLength);
                                            saveSetting("gameLength", gameLength);
                                            playerName = playerNameInput.text;
                                            saveSetting("playerName", playerName);

                                            buttonClicked(
                                            //getSetting('gameLength'));
                                            //console.log("retrieved " + gameLength);

                                            pageStack.push(playingScreen)


                                            //if (){


                                            //}



                                    )
                                  }

                          // Component.onCompleted: {
                                   //var gameLength = getSetting('gameLength');
                               //console.log("The value for gameLength is "+gameLength)
                                   //gameLengthToggle.selectedIndex = (gameLength === "Debian") ? 1 : 0;

                               }

            }

            Page {
                id: playingScreen
                visible: false





               title: i18n.tr("Round "+ gameLength)


               Component.onCompleted: {

                                                                   //var gameLength = getSetting('gameLength');
                                                               //console.log("The value for gameLength in playingScreen "+gameLength)

                                                                   //gameLengthToggle.selectedIndex = (gameLength === "Debian") ? 1 : 0;
                }

                   Label {

                      id: playerNameLabel

                      anchors.centerIn: parent
                            text: ("The Players Name is "+ playerName)

                      fontSize: "large"
                  }














            }

        }
    }
